@@ -1,5 +1,6 @@
 import os
-from gaelib.db import constants
+
+from . import constants
 
 
 def get_datastore_namespace():
