@@ -16,3 +16,6 @@ VERIFICATION_SID = ''
 ACCOUNT_SID = ''
 AUTH_TOKEN = ''
 TOKEN_LENGTH = 12
+
+# APNS Settings
+AUTH0_JKWS_DOMAIN = ''
