@@ -5,16 +5,21 @@ import jinja2
 from flask import g, Flask, request
 from google.cloud.logging.client import Client
 from google.cloud.logging.handlers.app_engine import AppEngineHandler
-from gaelib.env import (is_dev, 
-                        get_env, 
-                        get_dashboard_url_prefix, 
-                        get_sidebar_template, 
-                        get_app_or_default_prop)
+from gaelib.env import (is_dev,
+                        get_env,
+                        get_dashboard_url_prefix,
+                        get_dashboard_assets_prefix,
+                        get_sidebar_template,
+                        get_app_or_default_prop,
+                        get_twilio_account_sid,
+                        get_twilio_auth_token,
+                        get_twilio_verification_sid)
 from gaelib import filters
-from gaelib.urls import (auth_urls, 
-                        dashboard_lib_urls, 
-                        dashboard_lib_template_dir,
-                        client_logger_urls)
+from gaelib.urls import (auth_urls,
+                         verification_urls,
+                         dashboard_lib_urls,
+                         dashboard_lib_template_dir,
+                         client_logger_urls)
 
 PARAMETER_LOGGING = get_app_or_default_prop('PARAMETER_LOGGING')
 
@@ -50,12 +55,14 @@ def log_request_info():
   if request_json:
     g.app.logger.info('Request json: ' + str(request_json))
 
+
 @app.context_processor
 def inject_global_template_vars():
   return dict(app_name=get_app_or_default_prop('APP_NAME'), dashboard_prefix=get_dashboard_url_prefix(),
-              env=get_env(), sidebar_template=get_sidebar_template())
+              dashboard_assets_prefix=get_dashboard_assets_prefix(), env=get_env(), sidebar_template=get_sidebar_template())
 
-def startup(auth=True, parameter_logging=False, client_logging=False, dashboard=True):
+
+def startup(auth=True, parameter_logging=False, client_logging=False, dashboard=True, verification=True):
   """The startup script to create flask app and check if
       the application is running on local server or production.
   """
@@ -80,11 +87,18 @@ def startup(auth=True, parameter_logging=False, client_logging=False, dashboard=
     app.register_blueprint(dashboard_lib_urls)
 
   app.register_blueprint(filters.blueprint)
-  
-  app.secret_key = get_app_or_default_prop('SESSION_SECRET')   # Used for session management
+
+  app.secret_key = get_app_or_default_prop(
+      'SESSION_SECRET')   # Used for session management
+
+  if verification:
+    app.register_blueprint(verification_urls)
+    # Used for Twilio
+    app.config['VERIFICATION_SID'] = get_twilio_verification_sid()
+    app.config['ACCOUNT_SID'] = get_twilio_account_sid()
+    app.config['AUTH_TOKEN'] = get_twilio_auth_token()
 
   if client_logging:
     app.register_blueprint(client_logger_urls)
 
-
-  return app
\ No newline at end of file
+  return app
